@@ -3,7 +3,7 @@ import random
 
 import pytest
 
-from cvectors import Vector, angle
+from cvectors import Vector, _from_complex
 
 
 def random_vectors(n=1000):
@@ -64,22 +64,17 @@ def test_div_scale():
 
 def test_from_complex():
     for v in random_vectors():
-        assert v == Vector(complex(v.x, v.y))
-    assert Vector(2 + 3j) == Vector(2, 3)
-    assert Vector(1j) == Vector(0, 1)
-
-
-def test_from_iterable():
-    assert Vector((-1, 5)) == Vector(-1, 5)
-    assert Vector([-3, 9]) == Vector(-3, 9)
-    for v in random_vectors():
-        assert v == Vector((v.x, v.y)) == Vector([v.x, v.y])
+        assert v == _from_complex(complex(v.x, v.y))
+    assert _from_complex(2 + 3j) == Vector(2, 3)
+    assert _from_complex(1j) == Vector(0, 1)
 
 
 def test_from_bad_iterable():
-    with pytest.raises(ValueError):
+    with pytest.raises(TypeError):
         Vector([1])
-    with pytest.raises(ValueError):
+    with pytest.raises(TypeError):
+        Vector([1, 2])
+    with pytest.raises(TypeError):
         Vector([1, 2, 3])
 
 
@@ -117,8 +112,8 @@ def test_iteration():
 
 
 def test_properties():
-    assert Vector((2, 3)).x == 2
-    assert Vector((9, -3)).y == -3
+    assert Vector(2, 3).x == 2
+    assert Vector(9, -3).y == -3
 
 
 def test_r():
@@ -131,9 +126,9 @@ def test_r():
 
 
 def test_theta():
-    assert Vector((1, 1)).theta == math.pi / 4
-    assert Vector((0, -1)).theta == -math.pi / 2
-    assert Vector((-1, -1)).theta == -3 * math.pi / 4
+    assert Vector(1, 1).theta == math.pi / 4
+    assert Vector(0, -1).theta == -math.pi / 2
+    assert Vector(-1, -1).theta == -3 * math.pi / 4
     assert Vector.from_polar(r=2, theta=1).theta == 1
 
 
@@ -180,27 +175,14 @@ def test_round():
 
 def test_rotate():
     assert Vector(2, 3).rotate(math.pi).rec() == pytest.approx(Vector(-2, -3).rec())
-    assert Vector(2, 3).rotate(angle(90, "deg")).rec() == pytest.approx(Vector(-3, 2).rec())
-    assert Vector(2, 3).rotate(angle(1, "turn")).rec() == pytest.approx(Vector(2, 3).rec())
+    assert Vector(2, 3).rotate(math.pi / 2).rec() == pytest.approx(Vector(-3, 2).rec())
+    assert Vector(2, 3).rotate(math.tau).rec() == pytest.approx(Vector(2, 3).rec())
 
 
 def test_unary_minus():
     assert -Vector(-2, 0) == Vector(2, 0)
 
 
-def test_angles():
-    assert angle(30, "deg") == math.pi / 6
-    assert angle(2, "turn") == 2 * math.tau
-    assert angle(50, "g") == math.pi / 4
-    assert angle(-60 * 60, "min") == -math.pi / 3
-    assert angle(3600 * 90, "sec") == math.pi / 2
-    assert angle(3600 * 90, "sec") == math.pi / 2
-    assert angle(2, "rad") == 2
-    with pytest.raises(ValueError):
-        angle(1, "foo")
-        angle(1, "degres")
-
-
 def test_from_object():
     class Foo:
         def __init__(self, x, y):
@@ -245,151 +227,3 @@ def test_reversed():
     for _ in range(1000):
         vec = Vector(random.uniform(-999, 999), random.uniform(-999, 999))
         assert list(reversed(vec)) == list(reversed(list(vec)))
-
-
-def test_float_perf(benchmark):
-    benchmark(Vector, 1.5, 2.3)
-
-
-def test_int_perf(benchmark):
-    benchmark(Vector, -7, 35)
-
-
-def test_list_perf(benchmark):
-    benchmark(Vector, [93, -107.378])
-
-
-def test_polar_perf(benchmark):
-    benchmark(Vector.from_polar, 8.187, 2.17)
-
-
-def test_components_perf(benchmark):
-    def components(v):
-        return v.x, v.y
-
-    benchmark(components, Vector(-0.00319, 1.3789))
-
-
-def test_add_perf(benchmark):
-    def add(v1, v2):
-        return v1 + v2
-
-    benchmark(add, Vector(-113.131423, 13.1238), Vector(-39.23, 0.229))
-
-
-def test_sub_perf(benchmark):
-    def sub(v1, v2):
-        return v1 - v2
-
-    benchmark(sub, Vector(-19.129, -12.397), Vector(-45.21, 4912.397))
-
-
-def test_mul_perf(benchmark):
-    def mul(v, s):
-        return v * s
-
-    benchmark(mul, Vector(192.187, 52.137), 83.3897)
-
-
-def test_div_perf(benchmark):
-    def div(v, s):
-        return v / s
-
-    benchmark(div, Vector(71.278, -53.129), 67.12)
-
-
-def test_abs_perf(benchmark):
-    benchmark(abs, Vector(18.197, -12.13))
-
-
-def test_neg_perf(benchmark):
-    def neg(v):
-        return -v
-
-    benchmark(neg, Vector(81.12987, -789.871))
-
-
-def test_r_perf(benchmark):
-    def r(v):
-        return v.r
-
-    benchmark(r, Vector(-1293.138, 178341.18923))
-
-
-def test_theta_perf(benchmark):
-    def theta(v):
-        return v.theta
-
-    benchmark(theta, Vector(-1093.318, 89.13789))
-
-
-def test_dot_perf(benchmark):
-    def dot(v1, v2):
-        return v1.dot(v2)
-
-    benchmark(dot, Vector(-7.3417, -39.27), Vector(19.287, -71.73))
-
-
-def test_perp_dot_perf(benchmark):
-    def perp_dot(v1, v2):
-        return v1.perp_dot(v2)
-
-    benchmark(perp_dot, Vector(-2.1738, 3.197), Vector(1.19007, 6.179))
-
-
-def test_perp_perf(benchmark):
-    def perp(v):
-        return v.perp()
-
-    benchmark(perp, Vector(12.378, -17.1879))
-
-
-def test_hat_perf(benchmark):
-    def hat(v):
-        return v.hat()
-
-    benchmark(hat, Vector(61.378, 79.12879))
-
-
-def test_rotate_perf(benchmark):
-    def rotate(v, a):
-        return v.rotate(a)
-
-    benchmark(rotate, Vector(-3.12, 5.12), 5)
-
-
-def test_rec_perf(benchmark):
-    def rec(v):
-        return v.rec()
-
-    benchmark(rec, Vector(-6.13, 78.1378))
-
-
-def test_pol_perf(benchmark):
-    def pol(v):
-        return v.pol()
-
-    benchmark(pol, Vector(12.7283, 8.78))
-
-
-def test_index_perf(benchmark):
-    def index(v):
-        return (v[0], v[1])
-
-    benchmark(index, Vector(5.213, -7.12))
-
-
-def test_iter_perf(benchmark):
-    def iterate(v):
-        for i in v:
-            pass
-
-    benchmark(iterate, Vector(-72.1, 6.12))
-
-
-def test_repr_perf(benchmark):
-    benchmark(repr, Vector(6.23, -7.72))
-
-
-def test_str_perf(benchmark):
-    benchmark(str, Vector(-4.2, 9))
